.. pySciSci documentation master file, created by
   sphinx-quickstart on Mon Jun 21 10:54:47 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pySciSci's documentation!
**************************************

Table of Contents
===================
.. toctree::
   :maxdepth: 2

   about
   installation
   examples
   databases
   methods
   network
   utils


References
===================
.. bibliography::